@@ -4,11 +4,11 @@ from trytond.model import fields
 from trytond.pool import PoolMeta
 from trytond.pyson import Eval
 
-__all__ = ['Template']
-__metaclass__ = PoolMeta
+__all__ = ['Template', 'Product']
 
 
 class Template:
+    __metaclass__ = PoolMeta
     __name__ = 'product.template'
 
     supply_on_sale = fields.Boolean('Supply On Sale',
@@ -16,3 +16,8 @@ class Template:
             'invisible': ~Eval('purchasable') | ~Eval('salable'),
             },
         depends=['purchasable', 'salable'])
+
+
+class Product:
+    __metaclass__ = PoolMeta
+    __name__ = 'product.product'
